@@ -18,8 +18,10 @@
 #
 # Relief from the License may be granted by purchasing a commercial license.
 
+import argparse
 import os
 from datetime import datetime
+from distutils.log import debug
 from logging.handlers import DEFAULT_TCP_LOGGING_PORT
 from pathlib import Path
 
@@ -35,11 +37,14 @@ from covalent._results_manager import Result
 from covalent._results_manager import results_manager as rm
 from covalent._shared_files.config import get_config
 from covalent._shared_files.util_classes import Status
+from covalent_dispatcher._service.app import bp
 
 WEBHOOK_PATH = "/api/webhook"
 WEBAPP_PATH = "webapp/build"
+DEFAULT_PORT = 5000
 
 app = Flask(__name__, static_folder=WEBAPP_PATH)
+app.register_blueprint(bp)
 # allow cross-origin requests when API and static files are served separately
 CORS(app)
 socketio = SocketIO(app, cors_allowed_origins="*")
@@ -185,4 +190,36 @@ def serve(path):
 
 
 if __name__ == "__main__":
-    socketio.run(app)
+    ap = argparse.ArgumentParser()
+    ap.add_argument(
+        "-l",
+        "--log-file",
+        required=False,
+        help="Path to log file that will be written to by server.",
+    )
+    ap.add_argument("-p", "--port", required=False, help="Server port number.")
+    ap.add_argument(
+        "-d",
+        "--develop",
+        required=False,
+        action="store_true",
+        help="Start the server in developer mode.",
+    )
+    args, unknown = ap.parse_known_args()
+    # log file to be specified by cli
+    if args.log_file:
+        import logging
+
+        log_file = args.log_file
+        logging.basicConfig(
+            filename=log_file,
+            level=logging.DEBUG,
+            format="%(asctime)s %(levelname)s %(name)s %(threadName)s : %(message)s",
+        )
+    # port to be specified by cli
+    if args.port:
+        port = int(args.port)
+    else:
+        port = DEFAULT_PORT
+    debug = True if args.develop is True else False
+    socketio.run(app, debug=debug, host="0.0.0.0", port=port)
